@@ -12,14 +12,18 @@ get_train_template_id <- function() {
   id <- CIVIS_ML_TEMPLATE_IDS[CIVIS_ML_TEMPLATE_IDS$version == latest &
                               CIVIS_ML_TEMPLATE_IDS$name == "train", "id"]
 
-  # only check update if API key is set
   if (!inherits(try(api_key(), silent = TRUE), "try-error")) {
-    if (length(scripts_list_custom(id)) == 0) {
+    i <- 1
+    while (length(scripts_list_custom(id)) == 0 &&
+           i < length(versions)) {
       # use the previous version; assume that only the latest version is in internal release
-      prev <- versions[length(versions) - 1]
+      prev <- versions[length(versions) - i]
       id <- CIVIS_ML_TEMPLATE_IDS[CIVIS_ML_TEMPLATE_IDS$version == prev &
                                   CIVIS_ML_TEMPLATE_IDS$name == "train", "id"]
+      i <- i + 1
     }
   }
   return(id)
 }
+
+
