@@ -1,6 +1,7 @@
 library(testthat)
 library(civis)
 library(dplyr)
+library(future)
 
 # Smoke test for testing general end to end functions.  These tests hit
 # outside resources (Civis API, Redshift), so necessary credentials are
@@ -116,30 +117,6 @@ test_that("query_civis_file", {
   expect_equal(df1, df2)
 })
 
-test_that("DBI Read-Only connections forbid writes", {
-  tryCatch({
-    conn <- dbConnect(dbi_driver(), database = database, read_only = TRUE)
-    expect_error(dbWriteTable(conn, tablename = tablename, mpg))
-  }, finally = {
-    db_id <- get_database_id(database)
-    q <- queries_post(db_id, paste("DROP TABLE IF EXISTS", tablename), 1)
-  })
-})
-
-test_that("dplyr pipeline works", {
-  redshift <- dbConnect(dbi_driver(), database = database)
-  query <- tbl(redshift, "datascience.iris") %>%
-    select(-sepal_width) %>%
-    filter(petal_width < 3) %>%
-    group_by(type) %>%
-    summarize(mlength = mean(sepal_length), n = n()) %>%
-    mutate(n2 = log(n), n3 = n * 3, n4 = n - 10, n5 = n + 5)
-  show_query(query)
-  x <- collect(query)
-  expect_equal(nrow(x), 3)
-})
-
-
 ###############################################################################
 # Reports
 ###############################################################################
@@ -187,7 +164,8 @@ test_that("futures work", {
   d2 <- future({read_civis("datascience.iris", "redshift-general")})
   d <- read_civis("datascience.iris", verbose = TRUE)
   expect_is(d2, "CivisFuture")
-  expect_equal(d, value(d2))
+  d2 <- value(d2)
+  expect_equal(d[order(d$index), ], d2[order(d2$index), ], check.attributes = FALSE)
 })
 
 test_that("additional packages get installed", {
